@@ -14,6 +14,10 @@ class Viper:
                 test["array"] = True
     
     def importFromFile(self, data):
+        """
+        Import from another file\n
+        :param list data: A list of tests from another file. 
+        """
         for test in data:
             self.test(test["name"], test["functionOutput"], test["desiredOutput"])
     
